ORM helpers
===========

.. module:: sqlalchemy_utils.functions


cast_if
-------

.. autofunction:: cast_if


escape_like
-----------

.. autofunction:: escape_like


get_bind
--------

.. autofunction:: get_bind


get_class_by_table
------------------

.. autofunction:: get_class_by_table


get_column_key
--------------

.. autofunction:: get_column_key


get_columns
-----------

.. autofunction:: get_columns


get_declarative_base
--------------------

.. autofunction:: get_declarative_base


get_hybrid_properties
---------------------

.. autofunction:: get_hybrid_properties


get_mapper
----------

.. autofunction:: get_mapper


get_query_entities
------------------

.. autofunction:: get_query_entities


get_primary_keys
----------------

.. autofunction:: get_primary_keys


get_tables
----------

.. autofunction:: get_tables


get_type
--------

.. autofunction:: get_type


has_changes
-----------

.. autofunction:: has_changes


identity
--------

.. autofunction:: identity


is_loaded
---------

.. autofunction:: is_loaded


make_order_by_deterministic
---------------------------

.. autofunction:: make_order_by_deterministic


naturally_equivalent
--------------------

.. autofunction:: naturally_equivalent


quote
-----

.. autofunction:: quote


sort_query
----------

.. autofunction:: sort_query
